@@ -17,10 +17,11 @@ new StaticWebsite(this, 'StaticWebsite', {
     websiteContentPath: '<relative>/<path>/<to>/<built>/<website>',
     runtimeOptions: {
         jsonPayload: {
+            region: Stack.of(this).region,
             identityPoolId: userIdentity.identityPool.identityPoolId,
             userPoolId: userIdentity.userPool?.userPoolId,
-            userPoolClientId: userIdentity.userPoolClient?.userPoolClientId,
-        },
+            userPoolWebClientId: userIdentity.userPoolClient?.userPoolClientId,
+        }
     },
 });
 ```
